@@ -24,6 +24,7 @@ import (
 	"github.com/golang/mock/gomock"
 	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -37,9 +38,6 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 
-	cloudresourcemanager "google.golang.org/api/cloudresourcemanager/v1"
-	iamadminpb "google.golang.org/genproto/googleapis/iam/admin/v1"
-
 	minterv1 "github.com/openshift/cloud-credential-operator/pkg/apis/cloudcredential/v1"
 	mintergcp "github.com/openshift/cloud-credential-operator/pkg/gcp"
 	"github.com/openshift/cloud-credential-operator/pkg/gcp/actuator"
@@ -48,6 +46,10 @@ import (
 	gcpconst "github.com/openshift/cloud-credential-operator/pkg/operator/secretannotator/gcp"
 	"github.com/openshift/cloud-credential-operator/pkg/operator/utils"
 	schemeutils "github.com/openshift/cloud-credential-operator/pkg/util"
+	"github.com/openshift/cloud-credential-operator/pkg/util/clusteroperator"
+
+	cloudresourcemanager "google.golang.org/api/cloudresourcemanager/v1"
+	iamadminpb "google.golang.org/genproto/googleapis/iam/admin/v1"
 )
 
 const (
@@ -110,7 +112,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				testOperatorConfig(""),
 				createTestNamespace(testNamespace),
 				createTestNamespace(testSecretNamespace),
-				testGCPCredsSecret("kube-system", gcpconst.GCPCloudCredSecretName, testRootGCPAuth),
+				testGCPCredsSecret("kube-system", constants.GCPCloudCredSecretName, testRootGCPAuth),
 				testGCPCredentialsRequest(t),
 				testClusterVersion(),
 				testInfrastructure(testInfraName),
@@ -167,7 +169,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				createTestNamespace(testNamespace),
 				createTestNamespace(testSecretNamespace),
 				testGCPCredentialsRequest(t),
-				testGCPCredsSecret("kube-system", gcpconst.GCPCloudCredSecretName, testRootGCPAuth),
+				testGCPCredsSecret("kube-system", constants.GCPCloudCredSecretName, testRootGCPAuth),
 				testClusterVersion(),
 				testInfrastructure(""),
 			},
@@ -255,7 +257,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				createTestNamespace(testNamespace),
 				createTestNamespace(testSecretNamespace),
 				testGCPCredentialsRequest(t),
-				testGCPCredsSecret("kube-system", gcpconst.GCPCloudCredSecretName, testRootGCPAuth),
+				testGCPCredsSecret("kube-system", constants.GCPCloudCredSecretName, testRootGCPAuth),
 				testClusterVersion(),
 				testInfrastructure(testInfraName),
 			},
@@ -296,7 +298,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				createTestNamespace(testNamespace),
 				createTestNamespace(testSecretNamespace),
 				testGCPCredentialsRequest(t),
-				testGCPCredsSecret("kube-system", gcpconst.GCPCloudCredSecretName, testRootGCPAuth),
+				testGCPCredsSecret("kube-system", constants.GCPCloudCredSecretName, testRootGCPAuth),
 				testGCPCredsSecret(testSecretNamespace, testSecretName, testServiceAccountKeyPrivateData),
 				testClusterVersion(),
 				testInfrastructure(testInfraName),
@@ -337,7 +339,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				createTestNamespace(testNamespace),
 				createTestNamespace(testSecretNamespace),
 				testGCPCredentialsRequestWithDeletionTimestamp(t),
-				testGCPCredsSecret("kube-system", gcpconst.GCPCloudCredSecretName, testRootGCPAuth),
+				testGCPCredsSecret("kube-system", constants.GCPCloudCredSecretName, testRootGCPAuth),
 				testGCPCredsSecret(testSecretNamespace, testSecretName, testServiceAccountKeyPrivateData),
 				testClusterVersion(),
 				testInfrastructure(testInfraName),
@@ -363,7 +365,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				testOperatorConfig(""),
 				createTestNamespace(testSecretNamespace),
 				testGCPCredentialsRequest(t),
-				testGCPCredsSecret("kube-system", gcpconst.GCPCloudCredSecretName, testRootGCPAuth),
+				testGCPCredsSecret("kube-system", constants.GCPCloudCredSecretName, testRootGCPAuth),
 				testClusterVersion(),
 				testInfrastructure(testInfraName),
 			},
@@ -397,7 +399,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				testOperatorConfig(""),
 				createTestNamespace(testSecretNamespace),
 				testGCPCredentialsRequestWithDeletionTimestamp(t),
-				testGCPCredsSecret("kube-system", gcpconst.GCPCloudCredSecretName, testRootGCPAuth),
+				testGCPCredsSecret("kube-system", constants.GCPCloudCredSecretName, testRootGCPAuth),
 				testClusterVersion(),
 				testInfrastructure(testInfraName),
 			},
@@ -423,7 +425,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				testOperatorConfig(""),
 				createTestNamespace(testSecretNamespace),
 				testGCPCredentialsRequest(t),
-				testGCPCredsSecretPassthrough("kube-system", gcpconst.GCPCloudCredSecretName, testRootGCPAuth),
+				testGCPCredsSecretPassthrough("kube-system", constants.GCPCloudCredSecretName, testRootGCPAuth),
 				testClusterVersion(),
 				testInfrastructure(testInfraName),
 			},
@@ -457,7 +459,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				testOperatorConfig(""),
 				createTestNamespace(testSecretNamespace),
 				testGCPCredentialsRequest(t),
-				testGCPCredsSecretPassthrough("kube-system", gcpconst.GCPCloudCredSecretName, testRootGCPAuth),
+				testGCPCredsSecretPassthrough("kube-system", constants.GCPCloudCredSecretName, testRootGCPAuth),
 				testClusterVersion(),
 				testInfrastructure(testInfraName),
 			},
@@ -494,7 +496,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				testOperatorConfig(""),
 				createTestNamespace(testSecretNamespace),
 				testGCPPassthroughCredentialsRequest(t),
-				testGCPCredsSecretPassthrough("kube-system", gcpconst.GCPCloudCredSecretName, testRootGCPAuth),
+				testGCPCredsSecretPassthrough("kube-system", constants.GCPCloudCredSecretName, testRootGCPAuth),
 				testGCPCredsSecret(testSecretNamespace, testSecretName, testRootGCPAuth),
 				testClusterVersion(),
 				testInfrastructure(testInfraName),
@@ -527,7 +529,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				testOperatorConfig(""),
 				createTestNamespace(testSecretNamespace),
 				testGCPPassthroughCredentialsRequest(t),
-				testGCPCredsSecretPassthrough("kube-system", gcpconst.GCPCloudCredSecretName, testRootGCPAuth),
+				testGCPCredsSecretPassthrough("kube-system", constants.GCPCloudCredSecretName, testRootGCPAuth),
 				testGCPCredsSecret(testSecretNamespace, testSecretName, testOldPassthroughPrivateData),
 				testClusterVersion(),
 				testInfrastructure(testInfraName),
@@ -590,6 +592,8 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 				},
 				platformType: configv1.GCPPlatformType,
 			}
+			defer clusteroperator.ClearHandlers()
+			clusteroperator.AddStatusHandler(rcr)
 
 			_, err := rcr.Reconcile(reconcile.Request{
 				NamespacedName: types.NamespacedName{
@@ -619,7 +623,7 @@ func TestCredentialsRequestGCPReconcile(t *testing.T) {
 
 			for _, condition := range test.expectedCOConditions {
 				co := getClusterOperator(fakeClient)
-				assert.NotNil(t, co)
+				require.NotNil(t, co)
 				foundCondition := findClusterOperatorCondition(co.Status.Conditions, condition.conditionType)
 				assert.NotNil(t, foundCondition)
 				assert.Equal(t, string(condition.status), string(foundCondition.Status), "condition %s had unexpected status", condition.conditionType)
